/*
    DeaDBeeF -- the music player
    Copyright (C) 2009-2017 Alexey Yakovenko and other contributors

    This software is provided 'as-is', without any express or implied
    warranty.  In no event will the authors be held liable for any damages
    arising from the use of this software.

    Permission is granted to anyone to use this software for any purpose,
    including commercial applications, and to alter it and redistribute it
    freely, subject to the following restrictions:

    1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.

    2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.

    3. This notice may not be removed or altered from any source distribution.
*/

int
action_scan_all_tracks_without_rg_handler (struct DB_plugin_action_s *action, ddb_action_context_t ctx);

int
action_rg_scan_per_file_handler (struct DB_plugin_action_s *action, ddb_action_context_t ctx);

int
action_rg_remove_info_handler (struct DB_plugin_action_s *action, ddb_action_context_t ctx);

int
action_rg_scan_selection_as_albums_handler (struct DB_plugin_action_s *action, ddb_action_context_t ctx);

int
action_rg_scan_selection_as_album_handler (struct DB_plugin_action_s *action, ddb_action_context_t ctx);



